function [front,indices]=nonDominated(values,isMinFirst,isMinSecond)
% nonDominated(values) creates non-dominated front from given value array
% values: two-dimensional array with solutions
% isMinFirst: set to 1 when the first measure should be minimized, otherwise to 0
% isMinFirst: set to 1 when the second measure should be minimized, otherwise to 0
%
% Created on 01.02.2011 by Igor Vatolkin

if(length(values(:,1)) == 1)
    front = values;
    indices = 1;
    return;
end;

ndFrontSolutions = zeros(length(values),1);
for i=1:length(ndFrontSolutions)
    ndFrontSolutions(i)=1;
end;

for currentSolution=1:length(values)
    for currentSolutionToCompare=1:length(values)
        if(currentSolution == currentSolutionToCompare)
            continue;
        end;
        comp1 = comparison(values(currentSolution,1),values(currentSolutionToCompare,1),isMinFirst);
        comp2 = comparison(values(currentSolution,2),values(currentSolutionToCompare,2),isMinSecond);
        if((comp1 == 0 && comp2 == -1) || (comp1 == -1 && comp2 == 0) || (comp1 == -1 && comp2 == -1))
            % Current solution is dominated by another one and does not
            % belong to nd front!
            ndFrontSolutions(currentSolution) = 0;
            break;
        end;
    end;
end;

% Count the number of nd front solutions
counter = 0;
for i=1:length(ndFrontSolutions)
    if(ndFrontSolutions(i) == 1)
        counter =counter + 1;
    end;
end;

% Save the front and indicies of original solutions
frontWithIndices = zeros(counter,3);
counter = 0;
for i=1:length(ndFrontSolutions)
    if(ndFrontSolutions(i) == 1)
        counter = counter + 1;
        frontWithIndices(counter,1) = values(i,1);
        frontWithIndices(counter,2) = values(i,2);
        frontWithIndices(counter,3) = i;
    end;
end;

frontWithIndices = sortrows(frontWithIndices,1);
front = [frontWithIndices(:,1) frontWithIndices(:,2)];
indices = frontWithIndices(:,3);


function [res]=comparison(x,y,isMinimizing)

if(isMinimizing > 0) 
    if x < y  
        res = 1; % better!
    elseif(x == y)
        res = 0; % equal
    else
        res = -1; % worse
    end;
else
    if x > y 
        res = 1; % better!
    elseif(x == y)
        res = 0; % equal
    else
        res = -1; % worse
    end;
end;

