# ---------------------
# Helper functions
# ---------------------

# Map a track ID back to artist and track names
mapBackTrack <- function(track){
	tokens <- strsplit(track, ":")
	artist_name <- artists[strtoi(tokens[[1]][1])]
	track_name <- tracks[strtoi(tokens[[1]][2])]
	paste(artist_name, track_name, sep=" - ")
}

# Map the track IDs of a recommendation list back to artist and track names
mapBackRecoList <- function(recoList){
	mappedRecoList <- vector(mode = "character", length = 0)
	for (track in recoList){
		mappedTrack <- mapBackTrack(track)
		mappedRecoList <- c(mappedRecoList, mappedTrack)
	}
	mappedRecoList
}

# Display a recommendation list in a readable way
displayRecommendations <- function(recoList){
	for (i in 1:length(recoList)){
		line <- paste(i, recoList[i], sep=". ")
		cat(line, sep="\n")
	}
}

# Add a track to a playlist
addTrack <- function(artist, track, playlist){
	artist_id <- match(artist, artists);
	track_id <- match(track, tracks);
	playlist <- c(playlist, paste(artist_id, track_id, sep=":"))
	playlist
}

# Extract the artists of a playlist
extractArtists <- function(playlist){
	artists <- vector(mode = "character", length = 0)
	for (track in playlist){
		artist <- strsplit(track, ":")[[1]][1]
		if (!artist %in% artists){
			artists <- c(artists, artist)
		}
	}
	artists
}
